@@ -13,5 +13,5 @@ options = { 'baseurl':"", # if not set, relative URLs will be generated
             'slogan': "A website full of things Zed makes and says.",
             'extensions':['.txt'],
             'format': 'text/x-textile',
-            'siteurl': 'http://zedshaw.com',
+            'siteurl': 'http://lamsonproject.org',
         }
